# coding: utf-8

from eu2020.data.ev_others_ru import ev_others_ru

ev_others = []
ev_others += ev_others_ru

deep_others = {
    "RU": {
        "name": "Rusko",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 0,
    },
    "CN": {
        "name": "Čína",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 0,
    },
    "US": {
        "name": "USA",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 0,
    },
}
