# coding: utf-8

ev_higher_power = [
    {
        "key": "pandemic",
        "name": "Pandemie",
        "start": "Propukla pandemie nové neznámé choroby.",
        "end": "Pandemie ustoupila.",
    },
    {
        "key": "floods_de",
        "name": "Povodně v Německu",
        "start": "V Německu propukly povodně.",
        "end": "Povodně v Německu se podařilo zvládnout.",
    },
    {
        "key": "inflation",
        "name": "Inflace",
        "start": "Evropa se potýká s vysokou mírou inflace. Lidé se bojí o své úspory.",
        "end": "Inflaci se podařilo zvládnout.",
    },
    {
        "key": "economic_recession",
        "name": "Hospodářská recese",
        "start": "Evropou zmítá hospodářská recese, podniky propouštějí.",
        "end": "Hospodářskou recesi se podařilo zvládnout.",
    },
    {
        "key": "fires_gr",
        "name": "Požáry v Řecku",
        "start": "V Řecku propukly lesní požáry.",
        "end": "Lesní požáry v Řecku se podařilo zvládnout.",
    },
]
