header_1 = "yellow"
header_style = "cyan"
header_2 = "yellow"
option = "magenta"
cursor = "cyan"
proceed = "cyan"
numbers = "magenta"
high_power_events = "magenta"
positive_progress = "green"
negative_progress = "red"
